@@ -2,13 +2,20 @@
 set -euo pipefail
 cd "$(dirname "$0")"
 
-npm ci
-npm run check
+# Ubuntu 24.04 doesn't ship with ImageMagick v7
+if ! type magick &>/dev/null; then
+	shopt -s expand_aliases # https://unix.stackexchange.com/a/1498
+	alias magick=convert
+fi
 
 rm -rf ../wasm/pkg-fend-web
 (cd ../wasm && wasm-pack build --target web --out-dir pkg-fend-web)
 
-convert -resize "128x128" ../icon/icon.svg public/fend-icon-128.png
+npm ci
+npm run lint
+npm run format -- --check
+
+magick ../icon/icon.svg -resize "128x128" public/fend-icon-128.png
 
 mkdir -p public/documentation
 
